function y=my_log(x,tol)
% my_log - computes the natural logarithm 
% 
%   Syntax: 
%           y=my_log(x,tol)
%   Arguments: 
%           x - a positive number 
%           tol - a tolerance 
%   Returns: 
%           y - the natural logarithm of x, y=log(x)
%   Description:
%           The program uses the algorithm in the proof of the 
%           fundamental theorem to compute an approximation y of 
%           the natural logarithm such that 
%           |y-log(x)| < tol.  It returns an empty value if x
%           is not positive.  
%   Examples: 
%          y = my_log(x,1e-7)   computes log(x) to 7 decimals

%   See also:
%          
%

%----------------------------------------------------------------------
%   Bugs:
%
%   Date created: 
%          
%   Author:
%          
%
%   Change history:
%
%------------------------------+---------------------------------------+
Write your program here! 

